@@ -41,7 +41,7 @@ class StableDiffusionControlNetPoseGenerator:
 
         return self.pipe
 
-    def controlnet_pose(image_path: str):
+    def controlnet_pose(self, image_path: str):
         openpose = OpenposeDetector.from_pretrained("lllyasviel/ControlNet")
 
         image = Image.open(image_path)
@@ -99,13 +99,13 @@ class StableDiffusionControlNetPoseGenerator:
 
                     controlnet_pose_prompt = gr.Textbox(
                         lines=1,
-                        label="Prompt",
+                        show_label=False,
                         placeholder="Prompt",
                     )
 
                     controlnet_pose_negative_prompt = gr.Textbox(
                         lines=1,
-                        label="Negative Prompt",
+                        show_label=False,
                         placeholder="Negative Prompt",
                     )
 
