@@ -71,13 +71,15 @@ class StableDiffusionImage2ImageGenerator:
                     ).style(height=260)
 
                     image2image_prompt = gr.Textbox(
-                        lines=1, placeholder="Prompt", label="Prompt"
+                        lines=1,
+                        placeholder="Prompt",
+                        show_label=False,
                     )
 
                     image2image_negative_prompt = gr.Textbox(
                         lines=1,
                         placeholder="Negative Prompt",
-                        label="Negative Prompt",
+                        show_label=False,
                     )
 
                     with gr.Row():
@@ -85,15 +87,9 @@ class StableDiffusionImage2ImageGenerator:
                             image2image_model_path = gr.Dropdown(
                                 choices=stable_model_list,
                                 value=stable_model_list[0],
-                                label="Image-Image Model Id",
-                            )
-                            image2image_num_images_per_prompt = gr.Slider(
-                                minimum=1,
-                                maximum=30,
-                                step=1,
-                                value=1,
-                                label="Number Of Images",
+                                label="Stable Model Id",
                             )
+
                             image2image_guidance_scale = gr.Slider(
                                 minimum=0.1,
                                 maximum=15,
@@ -101,6 +97,13 @@ class StableDiffusionImage2ImageGenerator:
                                 value=7.5,
                                 label="Guidance Scale",
                             )
+                            image2image_num_inference_step = gr.Slider(
+                                minimum=1,
+                                maximum=100,
+                                step=1,
+                                value=50,
+                                label="Num Inference Step",
+                            )
                         with gr.Row():
                             with gr.Column():
                                 image2image_scheduler = gr.Dropdown(
@@ -108,6 +111,14 @@ class StableDiffusionImage2ImageGenerator:
                                     value=SCHEDULER_LIST[0],
                                     label="Scheduler",
                                 )
+                                image2image_num_images_per_prompt = gr.Slider(
+                                    minimum=1,
+                                    maximum=30,
+                                    step=1,
+                                    value=1,
+                                    label="Number Of Images",
+                                )
+
                                 image2image_seed_generator = gr.Slider(
                                     minimum=0,
                                     maximum=1000000,
@@ -116,14 +127,6 @@ class StableDiffusionImage2ImageGenerator:
                                     label="Seed(0 for random)",
                                 )
 
-                                image2image_num_inference_step = gr.Slider(
-                                    minimum=1,
-                                    maximum=100,
-                                    step=1,
-                                    value=50,
-                                    label="Num Inference Step",
-                                )
-
                     image2image_predict_button = gr.Button(value="Generator")
 
                 with gr.Column():
